@@ -1,4 +1,4 @@
-/* tftp-hpa: $Id: tftpsubs.c,v 1.3 2001/07/21 02:02:44 hpa Exp $ */
+/* tftp-hpa: $Id: tftpsubs.c,v 1.4 2001/08/03 03:17:57 hpa Exp $ */
 
 /* $OpenBSD: tftpsubs.c,v 1.2 1996/06/26 05:40:36 deraadt Exp $	*/
 /* $NetBSD: tftpsubs.c,v 1.3 1994/12/08 09:51:31 jtc Exp $	*/
@@ -42,7 +42,7 @@
 /* static char sccsid[] = "@(#)tftpsubs.c	8.1 (Berkeley) 6/6/93"; */
 /* static char rcsid[] = "$OpenBSD: tftpsubs.c,v 1.2 1996/06/26 05:40:36 deraadt Exp $"; */
 static const char *rcsid UNUSED =
-"tftp-hpa: $Id: tftpsubs.c,v 1.3 2001/07/21 02:02:44 hpa Exp $";
+"tftp-hpa: $Id: tftpsubs.c,v 1.4 2001/08/03 03:17:57 hpa Exp $";
 #endif /* not lint */
 
 /* Simple minded read-ahead/write-behind subroutines for tftp user and
@@ -59,12 +59,14 @@ static const char *rcsid UNUSED =
 #include <sys/types.h>
 #include <sys/socket.h>
 #include <sys/ioctl.h>
+#include <sys/time.h>
 #include <netinet/in.h>
 #include <arpa/tftp.h>
-
 #include <stdio.h>
 #include <unistd.h>
 
+#include "../config.h"
+
 #define PKTSIZE MAX_SEGSIZE+4       /* should be moved to tftp.h */
 
 int segsize = SEGSIZE;		/* Default segsize */
@@ -254,20 +256,28 @@ skipit:
 int
 synchnet(int f)		/* socket to flush */
 {
-	int i, j = 0;
-	char rbuf[PKTSIZE];
-	struct sockaddr_in from;
-	int fromlen;
+  int pktcount = 0;
+  char rbuf[PKTSIZE];
+  struct sockaddr_in from;
+  int fromlen;
+  fd_set socketset;
+  struct timeval notime;
+  
+  while ( 1 ) {
+    notime.tv_sec = notime.tv_usec = 0;
+    
+    FD_ZERO(&socketset);
+    FD_SET(f, &socketset);
+    
+    if ( select(f, &socketset, NULL, NULL, &notime) <= 0 )
+      break;			/* Nothing to read */
+	
+    /* Otherwise drain the packet */
+    pktcount++;
+    fromlen = sizeof from;
+    (void) recvfrom(f, rbuf, sizeof (rbuf), 0,
+		    (struct sockaddr *)&from, &fromlen);
+  }
 
-	while (1) {
-		(void) ioctl(f, FIONREAD, &i);
-		if (i) {
-			j++;
-			fromlen = sizeof from;
-			(void) recvfrom(f, rbuf, sizeof (rbuf), 0,
-				(struct sockaddr *)&from, &fromlen);
-		} else {
-			return(j);
-		}
-	}
+  return pktcount;		/* Return packets drained */
 }
